summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'CommentStreams/includes/ApiCSQueryComment.php')
-rw-r--r--CommentStreams/includes/ApiCSQueryComment.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/CommentStreams/includes/ApiCSQueryComment.php b/CommentStreams/includes/ApiCSQueryComment.php
index a27196ee..8112b7ee 100644
--- a/CommentStreams/includes/ApiCSQueryComment.php
+++ b/CommentStreams/includes/ApiCSQueryComment.php
@@ -23,22 +23,22 @@
namespace MediaWiki\Extension\CommentStreams;
-class ApiCSQueryComment extends ApiCSBase {
+use ApiMain;
+class ApiCSQueryComment extends ApiCSBase {
/**
* @param ApiMain $main main module
* @param string $action name of this module
*/
- public function __construct( $main, $action ) {
+ public function __construct( ApiMain $main, string $action ) {
parent::__construct( $main, $action );
}
/**
* the real body of the execute function
*
* @return result of API request
*/
- protected function executeBody() {
- return $this->comment->getJSON();
+ protected function executeBody() : ?array {
+ return $this->comment->getJSON( $this );
}
}
@@ -23,22 +23,22 @@
/**
* the real body of the execute function
- *
- * @return result of API request
+ * @return ?array result of API request
*/